# Amiga Library Services - CD Administration Makefile

CONTENTS_FORMAT = "==========\n\n%N    %V    %S\n\n%d\n\nAuthor: %a\nPath: %P\n\n"
INDEX_FORMAT =	"%-16.16N  %8.8V   %-S\n"
LOCATE_FORMAT =	"%-16.16N  %8.8V   %P\n"

SHELL =	/bin/sh

# This is the default thing to do.

all:	New.api CONTENTS.guide CONTENTS INDEX LOCATE


# Generate a summary file called "CONTENTS".  Note that the entries in the
# contents are generated in pathname sorted, case independent, order.

CONTENTS: PIList
	@echo >$@ "This file is generated automatically from the product info files"
	@echo >>$@ "included in this tree."
	@echo >>$@ ""
	pitool -f - -b -F $(CONTENTS_FORMAT) - <$? >>$@


# Generate an AmigaGuide format summary file called "CONTENTS.guide".

CONTENTS.guide: PIList GenCONTENTS.sh
	$(SHELL) GenCONTENTS.sh PIList >$@
	@if test  -f $@.info; then true; else echo "WARNING - missing $@.info"; fi


# Generate a quick reference file, which contains the name of the product,
# the version number, and the short description; one product per line.

INDEX:	PIList
	@echo >$@ "This file is generated automatically from the product info files"
	@echo >>$@ "included in this tree.  See the 'CONTENTS' file for additional"
	@echo >>$@ "information about each item."
	@echo >>$@ ""
	pitool -b -F $(INDEX_FORMAT) -f - - <$? | sort -f | uniq >>$@

# Generate a quick reference file, which contains the name of the product,
# the version number, and the short description; one product per line.

LOCATE:	PIList
	@echo >$@ "This file is generated automatically from the product info files"
	@echo >>$@ "included in this tree.  See the 'CONTENTS' file for additional"
	@echo >>$@ "information about each item."
	@echo >>$@ ""
	pitool -b -F $(LOCATE_FORMAT) -f - - <$? | sort -f | uniq >>$@

# Generate a list of all product-info files in this tree, sorted by the
# actual name of the product as recorded in the ".name" field and list
# with fully qualified pathnames (not relative names).
# Note that the sed command assumes that pwd returns the
# unix style name "/FreshFish-Vol10/..."

PIList:
	find . -type f -print \
	  | egrep -i "Product-Info$$|\.pi$$" \
	  | sed -e "s:^./:`pwd`/:" -e "s:^/::" -e "s@/@:@" \
	  | pitool -b -F "@%N@%i\n" -f - - \
	  | sort -f \
	  | sed -e "s:@.*@::" >$@

# Generate an accumulated product info file to use for searches.

New.api: PIList
	pitool -s - <$? >$@
	
# Clean up files that are trash.

clean:
	rm -f *! *~

# Remove all automatically generated files.

clobber: clean
	rm -f CONTENTS.guide CONTENTS INDEX LOCATE PIList New.api

